@@ -634,6 +634,15 @@ class AbstractWorker(threading.Thread):
     def add_stats_customer(self, customer_id, stats_name, stats_value):
         self.runtime_client.add_stats_customer(self.worker_type, self.get_id(), customer_id, stats_name, stats_value)
 
+    def add_stats_usage(self,  customer_id, job_id, job_name, stats_name, stats_value, labels = None):
+        self.runtime_client.add_stats_usage( worker_type=self.worker_type,
+                                             worker_id=self.get_id(),
+                                             customer_id=customer_id,
+                                             job_id=job_id,
+                                             job_name=job_name,
+                                             stats_name=stats_name,
+                                             stats_value=stats_value,
+                                             labels=labels)
 
     # start stop sekvencie
     def start_coordinator_client(self):
